==> humanCHRLOC_1.8.1.tar.gz: humanCHRLOC/man/humanCHRLOC21END.Rd <==
\name{humanCHRLOC21END}
\alias{humanCHRLOC21END}
\title{An annotation data file for transciption ending location of genes
on chromosome 21}
\description{
  humanCHRLOC21END mapps LocusLink ids to the transciption ending
  location of genes on chromosome number 21 corresponding to the
  LocusLink ids 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are LocusLink ids and values are the transciption ending location for
   genes. The ending positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors of length 1 derived from the
   largest end value found for the LocusLink id. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher5/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo_sapiens/database/}. Built: currentGenomes//Homo_sapiens

   Package built: Thu May 12 11:08:15 2005
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC21END)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}

==> humanCHRLOC_1.10.0.tar.gz: humanCHRLOC/man/humanCHRLOC21END.Rd <==
\name{humanCHRLOC21END}
\alias{humanCHRLOC21END}
\title{An annotation data file for transciption ending location of genes
on chromosome 21}
\description{
  humanCHRLOC21END mapps LocusLink ids to the transciption ending
  location of genes on chromosome number 21 corresponding to the
  LocusLink ids 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are LocusLink ids and values are the transciption ending location for
   genes. The ending positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors of length 1 derived from the
   largest end value found for the LocusLink id. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher5/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Homo_sapiens/database/}. Built: currentGenomes//Homo_sapiens

   Package built: Tue Oct  4 19:55:13 2005
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanCHRLOC21END)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}
